Retrieves detailed metadata for a specific dataset, including its configuration, schema, and status.
See also
Other Dataset Management Functions:
cto_dataset_create(),
cto_dataset_delete(),
cto_dataset_download(),
cto_dataset_list()
pkgdown/extra-header.html
Skip to contentsRetrieves detailed metadata for a specific dataset, including its configuration, schema, and status.
Other Dataset Management Functions:
cto_dataset_create(),
cto_dataset_delete(),
cto_dataset_download(),
cto_dataset_list()